# CLI-SHOW

## Introduction
* This is python package that you can simply check an image or .wav file on the Command Line Interface (CLI).
* It can be well used where you cannot download or checking data.
* Possible data type will be updated soon.

## Installation
```bash
pip install clishow
```
* It will automatically setup environment variable, so you can easily use it.

## Usage
### Image 
```bash
clishow ./image.png
```

### Audio (.wav)
```bash
clishow ./audio.wav
```
* Audio will be shown as signal image